const express = require('express');
const multer = require('multer');
const path = require('path');
const router = express.Router();
const db = require('./db/fileDb');
const {nanoid} = require('nanoid');
const config = require('./config')

const storage = multer.diskStorage({
   destination: (req, file, cb) => {
       cb(null, config.uploadPath);
   },
    filename: (req, file, cb) => {
       cb(null, nanoid() + path.extname(file.originalname))
    }
});
const upload = multer({storage})

db.init();

router.get('/', (req, res) => {
    const products = db.getItems();
    res.send(products)
});

router.get('/:id', (req, res) => {
    res.send('Single product will be here' + req.params.id)
});

router.post('/', upload.single('image'), (req, res) => {
    console.log('Create product', req.body);

    const newProduct = {
        ...req.body,
        _id: nanoid()
    };
    if(req.file) {
        newProduct.image = req.file.filename;
    }
    db.addItem(newProduct);
    res.send(newProduct)
});

module.exports = router;